#ifndef NT2_INCLUDE_FUNCTIONS_MANTISSA_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MANTISSA_HPP_INCLUDED

#include <nt2/ieee/include/functions/mantissa.hpp>

#endif
